@@ -211,13 +211,13 @@ class YOLOV6:
                             vid_writer = cv2.VideoWriter(save_path, cv2.VideoWriter_fourcc(*'mp4v'), fps, (w, h))
                         vid_writer.write(img_src)
             else:
-                return det
+                return det, class_names
             
 
     
 if __name__ == '__main__':
     model = YOLOV6(
-        weights='yolov6s.pt',
+        weights='yolov6s6.pt',
         device='cuda:0',
         hf_model=False,
     )
